/*  JPGalleg: JPEG loading routines for Allegro
 *
 *  version 1.1, by Angelo Mottola, May/June 2000
 *
 *  Example 2: how to load JPG images from a datafile already loaded in memory
 *
 *  See the README file for instruction on using this package!
 */

#include <allegro.h>
#include "jpgalleg.h"
#include "jpegdata.h"

int main()
{
   BITMAP *bmp;
   DATAFILE *data;

   allegro_init();
   install_keyboard();

   data = load_datafile("jpegdata.dat");
   if (!data) {
      allegro_message("Error loading jpegdata.dat!\n");
      return 1;
   }
   
   set_color_depth(16);
   if (set_gfx_mode(GFX_AUTODETECT, 640, 480, 0, 0)) {
      allegro_message("set_gfx_mode(): %s", allegro_error);
      return 1;
   }

   clear(screen);
   /* we don't care about the palette, as we're in hicolor mode */
   bmp = load_memory_jpg(data[JPG_00].dat, NULL);
   if (!bmp) {
      set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
      allegro_message("Error in the datafile\n");
      return 1;
   }
   blit(bmp, screen, 0, 0, 0, 0, bmp->w, bmp->h);
   /*
    * You must always destroy the bitmap, even if you loaded the jpg from the
    * datafile; infact, in the datafile memory there's the encoded version of
    * the image, and calling load_memory_jpg() creates a new bitmap, decoding
    * that data onto it. So you must destroy it when you're done with it.
    */
   destroy_bitmap(bmp);
   readkey();

   clear(screen);
   bmp = load_memory_jpg(data[JPG_01].dat, NULL);
   if (!bmp) {
      set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
      allegro_message("Error in the datafile\n");
      return 1;
   }
   blit(bmp, screen, 0, 0, 0, 0, bmp->w, bmp->h);
   destroy_bitmap(bmp);
   readkey();

   clear(screen);
   bmp = load_memory_jpg(data[JPG_02].dat, NULL);
   if (!bmp) {
      set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
      allegro_message("Error in the datafile\n");
      return 1;
   }
   blit(bmp, screen, 0, 0, 0, 0, bmp->w, bmp->h);
   destroy_bitmap(bmp);
   readkey();

   set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
   unload_datafile(data);
   return 0;
}
END_OF_MAIN()
